summaryrefslogtreecommitdiffstats
path: root/dcop/dcopclient.h
diff options
context:
space:
mode:
Diffstat (limited to 'dcop/dcopclient.h')
-rw-r--r--dcop/dcopclient.h27
1 files changed, 13 insertions, 14 deletions
diff --git a/dcop/dcopclient.h b/dcop/dcopclient.h
index 6c481b8af..41266c187 100644
--- a/dcop/dcopclient.h
+++ b/dcop/dcopclient.h
@@ -42,7 +42,7 @@ typedef TQValueList<TQCString> QCStringList;
*
* This class provides IPC and RPC for KDE applications. Usually you
* will not have to instantiate one yourself because KApplication
- * tqcontains a method to return a pointer to a DCOPClient object which
+ * contains a method to return a pointer to a DCOPClient object which
* can be used for your whole application.
*
* Before being able to send or receive any DCOP messages, you will have
@@ -65,10 +65,9 @@ typedef TQValueList<TQCString> QCStringList;
* @see KApplication::dcopClient()
* @author Preston Brown <pbrown@kde.org>, Matthias Ettrich <ettrich@kde.org>
*/
-class DCOP_EXPORT DCOPClient : public TQObject
+class DCOP_EXPORT DCOPClient : public QObject
{
Q_OBJECT
- TQ_OBJECT
public:
/**
@@ -84,7 +83,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
* Sets the address of a server to use upon attaching.
*
* If no server address is ever specified, attach will try its best to
* tqfind the server anyway.
* @param addr the new address of the server
*/
static void setServerAddress(const TQCString &addr);
@@ -346,7 +345,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
/**
* Searches for an object which matches a criteria.
*
* tqfindObject calls @p remFun in the applications and objects identified
* by @p remApp and @p remObj until @p remFun returns true. The name of
* the application and object that returned true are returned in
* @p foundApp and @p foundObj respectively.
@@ -354,7 +353,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
* If @p remFun is empty a default function is called in the object
* which always returns @p true.
*
* A tqfindObject blocks the application until the process receives the
* answer.
*
* If @p useEventLoop is true, a local event loop will be started after
@@ -379,7 +378,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
*
* @see send()
*/
- bool tqfindObject(const TQCString &remApp, const TQCString &remObj,
+ bool findObject(const TQCString &remApp, const TQCString &remObj,
const TQCString &remFun, const TQByteArray &data,
TQCString &foundApp, TQCString &foundObj,
bool useEventLoop/*=false*/, int timeout/*=-1*/);
@@ -388,7 +387,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
* @deprecated
*/
// KDE4 merge with above
- bool tqfindObject(const TQCString &remApp, const TQCString &remObj,
+ bool findObject(const TQCString &remApp, const TQCString &remObj,
const TQCString &remFun, const TQByteArray &data,
TQCString &foundApp, TQCString &foundObj,
bool useEventLoop=false);
@@ -512,7 +511,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
* @see process()
* @see beginTransaction()
*/
- TQ_INT32 transactionId() const;
+ Q_INT32 transactionId() const;
/**
* Checks whether @p remApp is registered with the DCOP server.
@@ -590,7 +589,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
* @param replyType write the reply type in this string
* @param replyData write the reply data in this array
*/
- bool tqfind(const TQCString &app, const TQCString &obj,
+ bool find(const TQCString &app, const TQCString &obj,
const TQCString &fun, const TQByteArray& data,
TQCString& replyType, TQByteArray &replyData);
@@ -694,7 +693,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
* to check whether a given client (by name) is running in the same
* process or in another one.
*/
- static DCOPClient* tqfindLocalClient( const TQCString &_appId );
+ static DCOPClient* findLocalClient( const TQCString &_appId );
/**
* @internal Do not use.
@@ -716,7 +715,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
* File with information how to reach the dcopserver.
* @param hostname Hostname to use, if empty current hostname of
* the system is used.
- * @return Filename that tqcontains information how to contact the
+ * @return Filename that contains information how to contact the
* DCOPserver.
*/
static TQCString dcopServerFile(const TQCString &hostname=0);
@@ -759,7 +758,7 @@ signals:
*
* Usually attached to a dialog box or some other visual
* aid.
- * @param msg the message tha tqcontains further information
+ * @param msg the message tha contains further information
*/
void attachFailed(const TQString &msg);
@@ -817,7 +816,7 @@ public:
private:
- bool isLocalTransactionFinished(TQ_INT32 id, TQCString &replyType, TQByteArray &replyData);
+ bool isLocalTransactionFinished(Q_INT32 id, TQCString &replyType, TQByteArray &replyData);
bool attachInternal( bool registerAsAnonymous = true );
@@ -84,7 +83,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
*
* If no server address is ever specified, attach will try its best to
- * tqfind the server anyway.
+ * find the server anyway.
* @param addr the new address of the server
*/
@@ -346,7 +345,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
* Searches for an object which matches a criteria.
*
- * tqfindObject calls @p remFun in the applications and objects identified
+ * findObject calls @p remFun in the applications and objects identified
* by @p remApp and @p remObj until @p remFun returns true. The name of
* the application and object that returned true are returned in
@@ -354,7 +353,7 @@ class DCOP_EXPORT DCOPClient : public TQObject
* which always returns @p true.
*
- * A tqfindObject blocks the application until the process receives the
+ * A findObject blocks the application until the process receives the
* answer.
*